@@ -485,6 +485,14 @@ void Part::slotLoadingFinished(KJob *job)
     if (job->error()) {
         if (arguments().metaData()[QLatin1String( "createNewArchive" )] != QLatin1String( "true" )) {
             KMessageBox::sorry(NULL, i18nc("@info", "Loading the archive <filename>%1</filename> failed with the following error: <message>%2</message>", localFilePath(), job->errorText()), i18nc("@title:window", "Error Opening Archive"));
+
+            // The file failed to open, so reset the open archive, info panel and caption.
+            m_model->setArchive(NULL);
+
+            m_infoPanel->setPrettyFileName(QString());
+            m_infoPanel->updateWithDefaults();
+
+            emit setWindowCaption(QString());
         }
     }
 
